==> okta-sdk-api-19.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/LogTarget.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LogTargetChangeDetails;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The entity that an actor performs an action on. Targets can be anything, such as an app user, a sign-in token, or
 * anything else.
 */
@ApiModel(description = "The entity that an actor performs an action on. Targets can be anything, such as an app user, a sign-in token, or anything else.")
@JsonPropertyOrder({ LogTarget.JSON_PROPERTY_ALTERNATE_ID, LogTarget.JSON_PROPERTY_CHANGE_DETAILS,
        LogTarget.JSON_PROPERTY_DETAIL_ENTRY, LogTarget.JSON_PROPERTY_DISPLAY_NAME, LogTarget.JSON_PROPERTY_ID,
        LogTarget.JSON_PROPERTY_TYPE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LogTarget implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALTERNATE_ID = "alternateId";
    private String alternateId;

    public static final String JSON_PROPERTY_CHANGE_DETAILS = "changeDetails";
    private LogTargetChangeDetails changeDetails;

    public static final String JSON_PROPERTY_DETAIL_ENTRY = "detailEntry";
    private Map<String, Object> detailEntry = null;

    public static final String JSON_PROPERTY_DISPLAY_NAME = "displayName";
    private String displayName;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public LogTarget() {
    }

    /*
     * @JsonCreator public LogTarget(
     *
     * @JsonProperty(JSON_PROPERTY_ALTERNATE_ID) String alternateId,
     *
     * @JsonProperty(JSON_PROPERTY_DETAIL_ENTRY) Map<String, Object> detailEntry,
     *
     * @JsonProperty(JSON_PROPERTY_DISPLAY_NAME) String displayName,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_TYPE) String type ) { this(); this.alternateId = alternateId; this.detailEntry =
     * detailEntry; this.displayName = displayName; this.id = id; this.type = type; }
     */

    /**
     * The alternate ID of the target
     *
     * @return alternateId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The alternate ID of the target")
    @JsonProperty(JSON_PROPERTY_ALTERNATE_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAlternateId() {
        return alternateId;
    }

    public LogTarget changeDetails(LogTargetChangeDetails changeDetails) {

        this.changeDetails = changeDetails;
        return this;
    }

    /**
     * Get changeDetails
     *
     * @return changeDetails
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CHANGE_DETAILS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LogTargetChangeDetails getChangeDetails() {
        return changeDetails;
    }

    @JsonProperty(JSON_PROPERTY_CHANGE_DETAILS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setChangeDetails(LogTargetChangeDetails changeDetails) {
        this.changeDetails = changeDetails;
    }

    /**
     * Further details on the target
     *
     * @return detailEntry
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Further details on the target")
    @JsonProperty(JSON_PROPERTY_DETAIL_ENTRY)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)

    public Map<String, Object> getDetailEntry() {
        return detailEntry;
    }

    /**
     * The display name of the target
     *
     * @return displayName
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The display name of the target")
    @JsonProperty(JSON_PROPERTY_DISPLAY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDisplayName() {
        return displayName;
    }

    /**
     * The ID of the target
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The ID of the target")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * The type of target
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The type of target")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LogTarget logTarget = (LogTarget) o;
        return Objects.equals(this.alternateId, logTarget.alternateId)
                && Objects.equals(this.changeDetails, logTarget.changeDetails)
                && Objects.equals(this.detailEntry, logTarget.detailEntry)
                && Objects.equals(this.displayName, logTarget.displayName) && Objects.equals(this.id, logTarget.id)
                && Objects.equals(this.type, logTarget.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(alternateId, changeDetails, detailEntry, displayName, id, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LogTarget {\n");
        sb.append("    alternateId: ").append(toIndentedString(alternateId)).append("\n");
        sb.append("    changeDetails: ").append(toIndentedString(changeDetails)).append("\n");
        sb.append("    detailEntry: ").append(toIndentedString(detailEntry)).append("\n");
        sb.append("    displayName: ").append(toIndentedString(displayName)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/LogTarget.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LogTargetChangeDetails;
import java.util.HashMap;
import java.util.Map;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * The entity that an actor performs an action on. Targets can be anything, such as an app user, a sign-in token, or
 * anything else.
 */
@ApiModel(description = "The entity that an actor performs an action on. Targets can be anything, such as an app user, a sign-in token, or anything else.")
@JsonPropertyOrder({ LogTarget.JSON_PROPERTY_ALTERNATE_ID, LogTarget.JSON_PROPERTY_CHANGE_DETAILS,
        LogTarget.JSON_PROPERTY_DETAIL_ENTRY, LogTarget.JSON_PROPERTY_DISPLAY_NAME, LogTarget.JSON_PROPERTY_ID,
        LogTarget.JSON_PROPERTY_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LogTarget implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ALTERNATE_ID = "alternateId";
    private String alternateId;

    public static final String JSON_PROPERTY_CHANGE_DETAILS = "changeDetails";
    private LogTargetChangeDetails changeDetails;

    public static final String JSON_PROPERTY_DETAIL_ENTRY = "detailEntry";
    private Map<String, Object> detailEntry = null;

    public static final String JSON_PROPERTY_DISPLAY_NAME = "displayName";
    private String displayName;

    public static final String JSON_PROPERTY_ID = "id";
    private String id;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public LogTarget() {
    }

    /*
     * @JsonCreator public LogTarget(
     *
     * @JsonProperty(JSON_PROPERTY_ALTERNATE_ID) String alternateId,
     *
     * @JsonProperty(JSON_PROPERTY_DETAIL_ENTRY) Map<String, Object> detailEntry,
     *
     * @JsonProperty(JSON_PROPERTY_DISPLAY_NAME) String displayName,
     *
     * @JsonProperty(JSON_PROPERTY_ID) String id,
     *
     * @JsonProperty(JSON_PROPERTY_TYPE) String type ) { this(); this.alternateId = alternateId; this.detailEntry =
     * detailEntry; this.displayName = displayName; this.id = id; this.type = type; }
     */

    /**
     * The alternate ID of the target
     *
     * @return alternateId
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The alternate ID of the target")
    @JsonProperty(JSON_PROPERTY_ALTERNATE_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getAlternateId() {
        return alternateId;
    }

    public LogTarget changeDetails(LogTargetChangeDetails changeDetails) {

        this.changeDetails = changeDetails;
        return this;
    }

    /**
     * Get changeDetails
     *
     * @return changeDetails
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_CHANGE_DETAILS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LogTargetChangeDetails getChangeDetails() {
        return changeDetails;
    }

    @JsonProperty(JSON_PROPERTY_CHANGE_DETAILS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setChangeDetails(LogTargetChangeDetails changeDetails) {
        this.changeDetails = changeDetails;
    }

    /**
     * Further details on the target
     *
     * @return detailEntry
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "Further details on the target")
    @JsonProperty(JSON_PROPERTY_DETAIL_ENTRY)
    @JsonInclude(content = JsonInclude.Include.ALWAYS, value = JsonInclude.Include.USE_DEFAULTS)

    public Map<String, Object> getDetailEntry() {
        return detailEntry;
    }

    /**
     * The display name of the target
     *
     * @return displayName
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The display name of the target")
    @JsonProperty(JSON_PROPERTY_DISPLAY_NAME)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getDisplayName() {
        return displayName;
    }

    /**
     * The ID of the target
     *
     * @return id
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The ID of the target")
    @JsonProperty(JSON_PROPERTY_ID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getId() {
        return id;
    }

    /**
     * The type of target
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The type of target")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LogTarget logTarget = (LogTarget) o;
        return Objects.equals(this.alternateId, logTarget.alternateId)
                && Objects.equals(this.changeDetails, logTarget.changeDetails)
                && Objects.equals(this.detailEntry, logTarget.detailEntry)
                && Objects.equals(this.displayName, logTarget.displayName) && Objects.equals(this.id, logTarget.id)
                && Objects.equals(this.type, logTarget.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(alternateId, changeDetails, detailEntry, displayName, id, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LogTarget {\n");
        sb.append("    alternateId: ").append(toIndentedString(alternateId)).append("\n");
        sb.append("    changeDetails: ").append(toIndentedString(changeDetails)).append("\n");
        sb.append("    detailEntry: ").append(toIndentedString(detailEntry)).append("\n");
        sb.append("    displayName: ").append(toIndentedString(displayName)).append("\n");
        sb.append("    id: ").append(toIndentedString(id)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
